```{include} ../README.md
:start-after: <!-- start docs-include-index -->
:end-before: <!-- end docs-include-index -->
```

## User's Guide

```{toctree}
---
maxdepth: 2
---

installation
usage
```

## API Reference

```{toctree}
---
maxdepth: 4
---

api
```

## Changelog

```{toctree}
---
maxdepth: 2
---

changelog
```
